@@ -1,5 +1,4 @@
 package Games::LMSolve::Base;
-our $AUTHORITY = 'cpan:SHLOMIF';
 
 use strict;
 use warnings;
@@ -476,7 +475,7 @@ Games::LMSolve::Base - base class for puzzle solvers.
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
 
 =head1 SYNOPSIS
 
@@ -515,7 +514,7 @@ the game.
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
 
 =head1 METHODS
 
@@ -647,7 +646,7 @@ Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Shlomi Fish.
+This software is Copyright (c) 2007 by Shlomi Fish.
 
 This is free software, licensed under:
 
@@ -656,8 +655,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Games-LMSolve or by email
-to bug-games-lmsolve@rt.cpan.org.
+L<https://github.com/shlomif/lm-solve-source/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -671,7 +669,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc Games::LMSolve
+  perldoc Games::LMSolve::Base
 
 =head2 Websites
 
@@ -686,7 +684,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-LMSolve>
+L<https://metacpan.org/release/Games-LMSolve>
 
 =item *
 
@@ -722,14 +720,6 @@ L<http://cpanratings.perl.org/d/Games-LMSolve>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-LMSolve>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -740,7 +730,7 @@ L<http://cpants.cpanauthors.org/dist/Games-LMSolve>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-LMSolve>
 
@@ -776,6 +766,6 @@ from your repository :)
 
 L<https://github.com/shlomif/lm-solve-source>
 
-  git clone https://github.com/shlomif/lm-solve-source.git
+  git clone git://github.com/shlomif/lm-solve-source.git
 
 =cut
