@@ -1,7 +1,5 @@
 package Games::LMSolve::Registry;
-$Games::LMSolve::Registry::VERSION = '0.10.1';
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Games::LMSolve::Registry::VERSION = '0.12.0';
 use strict;
 use warnings;
 
@@ -56,7 +54,7 @@ Games::LMSolve::Registry - the registry of all LM-Solve drivers.
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
 
 =head1 DESCRIPTION
 
@@ -64,7 +62,7 @@ This is a registry of all LM-Solve drivers.
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
 
 =head1 METHODS
 
@@ -86,7 +84,7 @@ Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Shlomi Fish.
+This software is Copyright (c) 2007 by Shlomi Fish.
 
 This is free software, licensed under:
 
@@ -95,8 +93,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Games-LMSolve or by email
-to bug-games-lmsolve@rt.cpan.org.
+L<https://github.com/shlomif/lm-solve-source/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -110,7 +107,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc Games::LMSolve
+  perldoc Games::LMSolve::Registry
 
 =head2 Websites
 
@@ -125,7 +122,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Games-LMSolve>
+L<https://metacpan.org/release/Games-LMSolve>
 
 =item *
 
@@ -161,14 +158,6 @@ L<http://cpanratings.perl.org/d/Games-LMSolve>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Games-LMSolve>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -179,7 +168,7 @@ L<http://cpants.cpanauthors.org/dist/Games-LMSolve>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/G/Games-LMSolve>
 
@@ -215,6 +204,6 @@ from your repository :)
 
 L<https://github.com/shlomif/lm-solve-source>
 
-  git clone https://github.com/shlomif/lm-solve-source.git
+  git clone git://github.com/shlomif/lm-solve-source.git
 
 =cut
