@@ -1,13 +1,16 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 
 use strict;
+use warnings;
 
-my @modules = 
+use autodie;
+
+my @modules =
     (
-        (map 
-            { 
-                "Games::LMSolve::$_" 
-            } 
+        (map
+            {
+                "Games::LMSolve::$_"
+            }
             qw(Numbers Base Plank::Base Plank::Hex Alice),
             qw(Tilt::Base Tilt::Single Tilt::Multi Tilt::RedBlue),
             qw(Input Registry)
@@ -17,23 +20,23 @@ my @modules =
 
 my $num_modules = scalar(@modules);
 
-open O, ">t/00use.t";
-print O <<"EOF" ;
+open my $out_fh, ">t/00use.t";
+print {$out_fh} <<"EOF" ;
 #!/usr/bin/perl -w
 
 use strict;
 
 use Test::More tests => $num_modules;
 
-BEGIN 
+BEGIN
 {
 EOF
 
 foreach (@modules)
 {
-    print O "use_ok(\"$_\");\n";
+    print {$out_fh} "use_ok(\"$_\");\n";
 }
 
-print O "}\n";
+print {$out_fh} "}\n";
 
-close(O);
+close ($out_fh);
